import * as PIXI from "pixi.js";
import globals from "./globals";

export function genButton(text, onUp, anchorX = 0.5, anchorY = 0.5) {
    const button = new PIXI.Graphics();
    const textElement = new PIXI.Text(text, globals.defaultStyle);
    textElement.anchor.set(anchorX, anchorY);
    button.addChild(textElement);
    const textBounds = textElement.getBounds();

    function draw(backgroundColor) {
        button.clear();
        button.beginFill(backgroundColor);
        button.lineStyle(2, 0xffffff);
        const margin = textBounds.height / 3;
        button.drawRoundedRect(
            textBounds.x - margin,
            textBounds.y - margin,
            textBounds.width + margin * 2,
            textBounds.height + margin * 2,
            5
        );
        button.endFill();
    }
    draw(0x101010);

    button.interactive = true;
    button.buttonMode = true;
    button.on("pointerout", () => {
        draw(0x101010);
    });
    button.on("pointerover", () => {
        draw(0x202020);
    });
    button.on("pointerup", () => {
        draw(0x202020);
        if (typeof onUp === "function") {
            onUp();
        }
    });
    button.on("pointerdown", () => {
        draw(0xf0f0f0);
    });

    return button;
}
