import * as PIXI from "pixi.js";

import "core-js/stable";
import "regenerator-runtime/runtime";

import "./index.scss";
import setup from "./setup";
import globals, { store } from "./globals";
import { setStage } from "./stages";
import { save } from "./reloader";
import { diffToText } from "./format";

function animate(delta) {
    const time = Date.now() / 1000;
    globals.uniforms.time = time - globals.timeStart;

    if (store.timeStart !== null) {
        globals.timer.text = diffToText(Date.now() - store.timeStart);
    } else {
        if (globals.timer.text.length > 0) {
            globals.timer.text = "";
        }
    }
}

function main() {
    const alertDialog = document.getElementById("warning");
    try {
        setup().then(() => {
            globals.timeStart = Date.now() / 1000;
            globals.app.ticker.add(animate);
        });
    } catch (e) {
        alertDialog.innerText = "Ohno, something went wrong";
        throw e;
    }
}

window.onload = main;

window.save = save;

window.dumpStore = () => {
    return JSON.stringify(store, null, 4).replaceAll('"', "'");
};
