import globals from "./globals";

import { store } from "./globals";

// Reload on resize with debounce
let timeout;
window.onresize = () => {
    // Abort if change is smaller than three pixels in either direction.
    //   This is necessarry because playing audio causes the window size to change by one pixel
    if (
        Math.abs(window.innerHeight - globals.window.height) < 3 &&
        Math.abs(window.innerWidth - globals.window.width) < 3
    ) {
        return;
    }
    window.clearTimeout(timeout);
    timeout = window.setTimeout(() => void window.location.reload(false), 300);
};

window.onbeforeunload = function () {
    if (globals.keepStorage) {
        save();
    } else {
        window.localStorage.clear();
    }
};

export function load() {
    for (const [key, value] of Object.entries(store)) {
        let storedValue = window.localStorage.getItem(key);
        if (storedValue === "null" || storedValue === null) {
            storedValue = null;
        } else if (storedValue === "undefined") {
            storedValue = undefined;
        } else if (!isNaN(storedValue)) {
            storedValue = parseFloat(storedValue);
        } else if (
            storedValue.length > 0 &&
            (storedValue[0] === "[" || storedValue[0] === "}")
        ) {
            storedValue = JSON.parse(value);
        }
        store[key] = storedValue ?? value;
    }
}

export function save() {
    for (const [key, value] of Object.entries(store)) {
        window.localStorage.setItem(key, value);
    }
}
