import * as PIXI from "pixi.js";
import { genButton } from "./button";

import globals, { store } from "./globals";
import * as reloader from "./reloader";
import * as stages from "./stages";

export default async function setup() {
    const alertDialog = document.getElementById("warning");
    alertDialog.innerText = "loading…";

    globals.app = new PIXI.Application({
        width: window.innerWidth,
        height: window.innerHeight,
        backgroundColor: "0x101010",
        resizeTo: window,
        antialias: true,
    });

    globals.uniforms = {
        time: 0,
        yoffset: (window.innerHeight - (window.innerWidth * 9.0) / 16.0) / 2.0,
    };

    globals.window.height = window.innerHeight;
    globals.window.width = window.innerWidth;

    globals.defaultStyle.fontSize = window.innerHeight * 0.05;

    reloader.load();

    await loadFonts();
    await stages.setup();
    stages.setStage(store.screen);

    const restart = () => {
        globals.keepStorage = false;
        window.location.reload(false);
    };
    window.restart = restart;
    const resetButton = genButton("Reset", restart);
    let buttonBounds = resetButton.getBounds();
    resetButton.position.set(
        window.innerWidth + buttonBounds.x,
        -buttonBounds.y
    );
    globals.app.stage.addChild(resetButton);

    const timerFont = PIXI.BitmapFont.from(
        globals.defaultStyle.fontFamily,
        {
            ...globals.defaultStyle,
        },
        {
            chars: [["0", "9"], ".:"],
        }
    );
    globals.timer = new PIXI.BitmapText("", {
        ...globals.defaultStyle,
        fontName: globals.defaultStyle.fontFamily,
    });

    globals.app.stage.addChild(globals.timer);

    document.getElementById("pixi").appendChild(globals.app.view);
    alertDialog.innerText = "";
}

const fonts = [
    /*{
        name: "Computer Speak",
        url: "https://fontlibrary.org/assets/fonts/computer-speak/bcab51f963cf3cb07cbaf1e0f3fda938/8ce5352df3399f4db8b466a8df41b56a/ComputerSpeakv02Regular.ttf",
    },
    {
        name: "Open Sans",
        url: "https://cdnlib.net/ar/font/open-sans/Open-Sans.woff2",
    },
    {
        name: "Android Regular",
        url: "https://fontlibrary.org/assets/fonts/android-7/edb9e4820e70dbe06c5ab760a5054348/c6d0c3476f03737f8893e7e596ab8aef/Android7Regular.ttf",
    },
    {
        name: "Source Sans",
        url: "https://www.fontsquirrel.com/presentation/theme_site/fonts/source_sans_pro/sourcesanspro-bold-webfont.woff",
    },
    {
        name: "Natural Mono",
        url: "https://fontlibrary.org/assets/fonts/natural-mono/71247908da88c4adad4219724e219aff/f972331d46093843a279f5f117b58b7c/NaturalMonoRegular.ttf",
    },*/
    {
        name: "AseaRegular",
        url: "https://fontlibrary.org/assets/fonts/asea-textfonts/2beee6bb9f51af24873d6d723ab6e972/89db42ab11bbb994f4ec95aba2d234d1/AseaRegular.ttf",
    },
];

function loadFonts() {
    const promises = [];
    const style = new PIXI.TextStyle({
        fill: "white",
        align: "center",
    });
    const chars = [["a", "z"], ["A", "Z"], ["0", "9"], ',.;:-+ "'];

    for (const [index, fontData] of fonts.entries()) {
        const promise = new Promise(async (resolve, reject) => {
            const fontFace = new FontFace(
                fontData.name,
                `url(${fontData.url})`
            );
            const font = await fontFace.load();
            document.fonts.add(font);
            fonts[index].name = font.fontFamily;
            fonts[index].bitmapFont = PIXI.BitmapFont.from(
                font.family,
                {
                    ...style,
                    fontFamily: font.family,
                },
                {
                    resolution: 5,
                    chars: chars,
                }
            );
            resolve();
        });
        promises.push(promise);
    }

    return Promise.all(promises);
}
