import * as PIXI from "pixi.js";

import seedrandom from "seedrandom";

import globals, { store } from "./globals.js";
import hostOrJoin from "./stages/hostOrJoin.js";
import mainMenu from "./stages/mainMenu.js";
import hostGame from "./stages/hostGame.js";
import joinGame from "./stages/joinGame.js";
import startGame from "./stages/startGame.js";
import gameEnd from "./stages/gameEnd.js";
import cablePuzzle from "./stages/cablePuzzle.js";
import wordPuzzle from "./stages/wordPuzzle.js";
import ohno from "./stages/ohno.js";

let stages = [
    hostOrJoin,
    mainMenu,
    hostGame,
    joinGame,
    startGame,
    gameEnd,
    ohno,
    cablePuzzle,
    wordPuzzle,
];
let puzzles = [cablePuzzle, wordPuzzle];

export async function setup() {
    const container = new PIXI.Container();
    container.name = "stages";

    const loadingStages = [];
    for (const stage of stages) {
        loadingStages.push(stage.setup());
    }

    await Promise.all(loadingStages);
    container.addChild(...stages);
    globals.app.stage.addChild(container);
}

export function getRandomPuzzle() {
    if (store.code === null || store.finishedPuzzles === null) {
        console.warn("Get Random called without code set");
    }
    const gen = new seedrandom(store.code + store.finishedPuzzles.toString());

    return puzzles[Math.floor(gen() * puzzles.length)].name;
}

export async function setStage(screen) {
    console.log(`Changing Stage to "${screen}"`);

    store.screen = screen;

    let deferedLoad;
    let found = false;
    for (const stage of stages) {
        if (stage.name === screen) {
            stage.visible = true;
            deferedLoad = await stage.activate();
            found = true;
        } else {
            stage.visible = false;
        }
    }

    if (screen === "random_puzzle") {
        setStage(getRandomPuzzle());
        found = true;
    }

    if (!found) {
        setStage("ohno");
    } else if (typeof deferedLoad !== "undefined") {
        setStage(deferedLoad);
    }
}
