import * as PIXI from "pixi.js";
import "@pixi/graphics-extras";

import globals, { store } from "../globals.js";
import { setStage } from "../stages.js";
import { Stage } from "./stage.js";
import { genButton } from "../button.js";

const stage = new Stage("join_game", setup, activate);
export default stage;

const alphanums = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";

function makeTriangleButton(dir, size) {
    size *= 0.5;
    const height = Math.sqrt(size ** 2 - (size / 2) ** 2);

    const triangle = new PIXI.Graphics();
    triangle.beginFill(0xffffff);
    triangle.drawRegularPolygon(
        0,
        height,
        size,
        3,
        Math.PI * (dir === "up" ? 0 : 1)
    );
    triangle.endFill();

    return triangle;
}

function makeRow(handler) {
    function handle(dir) {
        return () => {
            const offset = dir === "up" ? 1 : -1;
            let newPos =
                (alphanums.indexOf(letter.text) + offset) % alphanums.length;
            // Bug in JS Modulo
            if (newPos < 0) {
                newPos += alphanums.length;
            }
            letter.text = alphanums[newPos];
            handler(dir, alphanums[newPos]);
        };
    }

    const row = new PIXI.Container();

    const letter = new PIXI.Text("A", globals.defaultStyle);
    let letterBounds = letter.getBounds();
    letter.anchor.set(0.5, 0);
    letter.position.y = letterBounds.height;
    letter.position.x = 0;

    const upButton = makeTriangleButton("up", letterBounds.height);
    upButton.position.set(0, 0);
    upButton.interactive = true;
    upButton.buttonMode = true;
    upButton.on("pointerdown", handle("up", letter));

    const downButton = makeTriangleButton("down", letterBounds.height);
    downButton.position.set(0, letterBounds.height * 2);
    downButton.interactive = true;
    downButton.buttonMode = true;
    downButton.on("pointerdown", handle("down", letter));

    row.addChild(upButton);
    row.addChild(letter);
    row.addChild(downButton);

    const bounds = row.getBounds();
    row.position.set(
        window.innerWidth / 2,
        (window.innerHeight - bounds.height) / 2
    );

    return { row, letter };
}

function rowHandler(pos) {
    return (dir, letter) => {
        let firstPart = store.code.substr(0, pos);
        let lastPart = store.code.substr(pos + 1);

        store.code = firstPart + letter + lastPart;
    };
}

function setup() {
    const textInstruction = new PIXI.Text(
        "Enter Room Code",
        globals.defaultStyle
    );
    textInstruction.anchor.set(0.5, 0.5);
    textInstruction.position.set(window.innerWidth / 2, window.innerHeight / 4);
    stage.addChild(textInstruction);

    const inputWidth = window.innerWidth / 4;
    for (let i = 0; i < 4; i++) {
        const row = makeRow(rowHandler(i));
        row.row.position.x += -inputWidth / 2 + (inputWidth / 3) * i;
        stage.addChild(row.row);
    }
    const startGame = genButton("Start Game", () => {
        setStage("start_game");
    });
    startGame.position.set(window.innerWidth / 2, (window.innerHeight * 3) / 4);

    stage.addChild(startGame);
}

function activate() {
    store.code = "AAAA";
    store.player = "B";
}
