const path = require("path");
const HtmlWebpackPlugin = require("html-webpack-plugin");

module.exports = (env) => {
    const isProduction = env === "production";
    return {
        entry: path.resolve(__dirname, "./src/index.js"),
        module: {
            rules: [
                {
                    test: /\.m?js$/,
                    exclude: /(node_modules|bower_components)/,
                    use: {
                        loader: "babel-loader",
                        options: {
                            presets: ["@babel/preset-env"],
                        },
                    },
                },
                {
                    test: /\.(s(a|c)ss|css)$/,
                    use: ["style-loader", "css-loader", "sass-loader"],
                },
            ],
        },
        resolve: {
            extensions: [".js"],
        },
        output: {
            path: path.resolve(__dirname, "./dist"),
            publicPath: "/starge-shmerzn/",
            filename: "bundle.js",
        },
        plugins: [
            new HtmlWebpackPlugin({
                template: path.resolve(__dirname, "./src/index.html"),
            }),
        ],
        devServer: {
            static: {
                directory: path.resolve(__dirname, "./dist"),
                serveIndex: true,
                watch: true,
            },
        },
        devtool: isProduction ? "source-map" : "inline-source-map",
        target: ["web", "es5"],
    };
};
